import React, { CSSProperties, Component, Ref } from 'react';
type NetworkLink<LinkOptions> = (url: string, options: LinkOptions) => string;
type WindowPosition = 'windowCenter' | 'screenCenter';
interface CustomProps<LinkOptions> {
    children?: React.ReactNode;
    /**
     * Disables click action and adds `disabled` class
     */
    disabled?: boolean;
    /**
     * Style when button is disabled
     * @default { opacity: 0.6 }
     */
    disabledStyle?: React.CSSProperties;
    forwardedRef?: Ref<HTMLButtonElement>;
    networkName: string;
    networkLink: NetworkLink<LinkOptions>;
    onClick?: (event: React.MouseEvent<HTMLButtonElement>, link: string) => void;
    openShareDialogOnClick?: boolean;
    opts: LinkOptions;
    /**
     * URL of the shared page
     */
    url: string;
    style?: React.CSSProperties;
    windowWidth?: number;
    windowHeight?: number;
    windowPosition?: WindowPosition;
    /**
     *  Takes a function that returns a Promise to be fulfilled before calling
     * `onClick`. If you do not return promise, `onClick` is called immediately.
     */
    beforeOnClick?: () => Promise<void> | void;
    /**
     * Takes a function to be called after closing share dialog.
     */
    onShareWindowClose?: () => void;
    resetButtonStyle?: boolean;
    blankTarget?: boolean;
    size?: number;
    round?: boolean;
    borderRadius?: number;
    iconStyle?: CSSProperties;
    iconFillColor?: string;
    bgColor?: string;
}
export type Props<LinkOptions> = Omit<React.ButtonHTMLAttributes<HTMLButtonElement>, keyof CustomProps<LinkOptions>> & CustomProps<LinkOptions>;
export default class SocialShareButton<LinkOptions> extends Component<Props<LinkOptions>> {
    static defaultProps: {
        disabledStyle: {
            opacity: number;
        };
        openShareDialogOnClick: boolean;
        resetButtonStyle: boolean;
    };
    openShareDialog: (link: string) => void;
    handleClick: (event: React.MouseEvent<HTMLButtonElement>) => Promise<void>;
    render(): React.JSX.Element;
}
export {};
